@@ -4,6 +4,17 @@ use 5.012;
 use strict;
 use warnings;
 use Carp qw(croak);
+use Test::OnlySome::PathCapsule;
+#use Data::Dumper;
+
+our $VERSION = '0.000007';
+use constant DEFAULT_FILENAME => '.onlysome.yml';
+
+our $Filename;  # The output filename to use, where the formatter can read it.
+
+# TODO someday: find a cleaner way to pass the filename to the formatter.  I am
+# not instantiating the formatter here because I don't want to remove
+# prove(1)'s control of the formatter options.
 
 # Docs {{{3
 
@@ -15,7 +26,7 @@ App::Prove::Plugin::Test::OnlySomeP - prove plugin supporting Test::OnlySome
 
 See L<Test::OnlySome>, with which this module is distributed.
 
-=head1 USAGE
+=head1 SYNOPSIS
 
     prove -PTest::OnlySomeP
 
@@ -36,13 +47,18 @@ The entry point for the plugin.
 
 sub load {
     my ($class, $prove) = @_;
+    my %args = @{ $prove->{args} };
+    print STDERR '# ', __PACKAGE__, " $VERSION loading\n";    # " with args ", Dumper(\%args), "\n";
 
-    print STDERR __PACKAGE__, " loading\n";
+    $Filename = Test::OnlySome::PathCapsule->new(
+        $args{filename} // DEFAULT_FILENAME
+    )->abs();
+    #print STDERR "Output filename is $Filename\n";
     $prove->{app_prove}->formatter('App::Prove::Plugin::Test::OnlySomeP::Formatter');
-} #skip_these()
+} #load()
 
 # }}}1
-# More docs, and $VERSION {{{3
+# More docs {{{3
 =head1 AUTHOR
 
 Christopher White, C<< <cxwembedded at gmail.com> >>
@@ -87,15 +103,6 @@ L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-OnlySome>
 =cut
 
 # }}}3
-
-our $VERSION = '0.000006';
-
-=head1 VERSION
-
-Version 0.0.6
-
-=cut
-
 # License {{{3
 
 =head1 ACKNOWLEDGEMENTS
@@ -134,5 +141,4 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 # }}}3
 1;
-
 # vi: set fdm=marker fdl=2: #
